# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .base_filter import Filter  # noqa
from .clipper import Clipper  # noqa
from .color import Alpha, ColorFilter, IsolineFilter, ZColormapFilter  # noqa
from .picking import PickingFilter  # noqa
from .mesh import TextureFilter, ShadingFilter, InstancedShadingFilter, WireframeFilter  # noqa
